==> phpnuke-5.5.tgz: www/phpnuke/html/modules/News/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Envoyer");
define("_URL","URL");
define("_PRINTER","Format imprimable");
define("_FRIEND","Envoyer cet article &agrave; un(e) ami(e)");



define("_YOURNAME","Votre Nom");

define("_OK","Ok !");
define("_RELATED","Liens connexes");
define("_MOREABOUT","Plus &agrave; propos de");
define("_NEWSBY","Nouvelles transmises par");
define("_MOSTREAD","L'article le plus lu &agrave; propos de");
define("_READMORE","Suite...");
define("_BYTESMORE","octets de plus");
define("_COMMENTSQ","commentaires ?");
define("_COMMENT","commentaire");

define("_CONFIGURE","Pr&eacute;f&eacute;rences");
define("_LOGINCREATE","Connexion/Cr&eacute;er un compte");
define("_THRESHOLD","Disposition");
define("_NOCOMMENTS","Pas de commentaires");
define("_NESTED","Emboit&eacute;s");
define("_FLAT","A plat");
define("_THREAD","Par discussions");
define("_OLDEST","Le plus vieux en premier");
define("_NEWEST","Le plus r&eacute;cent en premier");
define("_HIGHEST","Le plus haut score en premier");
define("_COMMENTSWARNING","Les commentaires sont la propri&eacute;t&eacute; de leurs auteurs. Nous ne sommes pas responsables de leurs contenus !");
define("_SCORE","Score:");


define("_USERINFO","Profil Utilisateur");
define("_READREST","Lire le reste du commentaire...");
define("_REPLY","R&eacute;pondre &agrave; ce message");
define("_REPLYMAIN","Poster un commentaire");
define("_NOSUBJECT","Pas de Sujet");
define("_NOANONCOMMENTS","Les commentaires anonymes ne sont pas autoris&eacute;s, veuillez vous <a href=\"user.php\">enregistrer</a>");
define("_PARENT","Parent");
define("_ROOT","Racine");

define("_UCOMMENT","Commentaire");
define("_ALLOWEDHTML","HTML autoris&eacute;:");
define("_POSTANON","Publication anonyme");
define("_EXTRANS","Extrans (html tags en texte)");
define("_HTMLFORMATED","Format HTML");
define("_PLAINTEXT","Texte seulement");
define("_ONN","le...");
define("_SUBJECT","Sujet");
define("_COMMENTREPLY","Commenter");
define("_COMREPLYPRE","Pr&eacute;visualisation du commentaire");
define("_NOTRIGHT","Quelque chose s'est mal d&eacute;roul&eacute; en passant une variable &agrave; cette fonction. Ceci est un message d'avertissement pour pr&eacute;venir d'un probable disfonctionnement.");
define("_SENDAMSG","Envoyer un message");
define("_YOUSENDSTORY","Vous allez envoyer l'article");
define("_TOAFRIEND","&agrave; l'ami(e) suivant(e):");
define("_FYOURNAME","Votre nom:");
define("_FYOUREMAIL","Votre E-mail:");
define("_FFRIENDNAME","Nom de votre ami(e):");
define("_FFRIENDEMAIL","E-mail de votre ami(e):");
define("_INTERESTING","Lu sur");
define("_HELLO","Bonjour");
define("_YOURFRIEND","Votre ami(e)");
define("_CONSIDERED","a trouv l'article suivant intressant et a souhait vous l'envoyer.");
define("_FDATE","Date:");
define("_FTOPIC","Sujet:");
define("_YOUCANREAD","Vous pouvez lire d'autres articles intressant sur");
define("_FSTORY","L'article");
define("_HASSENT"," a &eacute;t&eacute; envoy&eacute; &agrave;");
define("_THANKS","Merci!");
define("_RECOMMEND","Recommander ce site &agrave; un(e) ami(e)");
define("_PDATE","Date:");
define("_PTOPIC","Sujet:");
define("_COMESFROM","Cet article provient de");
define("_THEURL","L'URL de cet article est:");





define("_PREVIEW","Prvisualisation");
define("_NEWUSER","Nouvel Utilisateur");
define("_OPTIONS","Options");


define("_REFRESH","Rafra&icirc;chir");
define("_ADD","Ajouter");
define("_NOCOMMENTSACT","Dsol, les Commentaires ne sont pas autoriss pour cet article.");
define("_ARTICLEPOLL","Sondage de l'arcticle");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/News/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_SEND","Envoyer");
define("_URL","URL");
define("_PRINTER","Format imprimable");
define("_FRIEND","Envoyer cet article &agrave; un(e) ami(e)");



define("_YOURNAME","Votre Nom");

define("_OK","Ok !");
define("_RELATED","Liens connexes");
define("_MOREABOUT","Plus &agrave; propos de");
define("_NEWSBY","Nouvelles transmises par");
define("_MOSTREAD","L'article le plus lu &agrave; propos de");
define("_READMORE","Suite...");
define("_BYTESMORE","octets de plus");
define("_COMMENTSQ","commentaires ?");
define("_COMMENT","commentaire");

define("_CONFIGURE","Pr&eacute;f&eacute;rences");
define("_LOGINCREATE","Connexion/Cr&eacute;er un compte");
define("_THRESHOLD","Disposition");
define("_NOCOMMENTS","Pas de commentaires");
define("_NESTED","Emboit&eacute;s");
define("_FLAT","A plat");
define("_THREAD","Par discussions");
define("_OLDEST","Le plus vieux en premier");
define("_NEWEST","Le plus r&eacute;cent en premier");
define("_HIGHEST","Le plus haut score en premier");
define("_COMMENTSWARNING","Les commentaires sont la propri&eacute;t&eacute; de leurs auteurs. Nous ne sommes pas responsables de leurs contenus !");
define("_SCORE","Score:");


define("_USERINFO","Profil Utilisateur");
define("_READREST","Lire le reste du commentaire...");
define("_REPLY","R&eacute;pondre &agrave; ce message");
define("_REPLYMAIN","Poster un commentaire");
define("_NOSUBJECT","Pas de Sujet");
define("_NOANONCOMMENTS","Les commentaires anonymes ne sont pas autoris&eacute;s, veuillez vous <a href=\"user.php\">enregistrer</a>");
define("_PARENT","Parent");
define("_ROOT","Racine");

define("_UCOMMENT","Commentaire");
define("_ALLOWEDHTML","HTML autoris&eacute;:");
define("_POSTANON","Publication anonyme");
define("_EXTRANS","Extrans (html tags en texte)");
define("_HTMLFORMATED","Format HTML");
define("_PLAINTEXT","Texte seulement");
define("_ONN","le...");
define("_SUBJECT","Sujet");
define("_COMMENTREPLY","Commenter");
define("_COMREPLYPRE","Pr&eacute;visualisation du commentaire");
define("_NOTRIGHT","Quelque chose s'est mal d&eacute;roul&eacute; en passant une variable &agrave; cette fonction. Ceci est un message d'avertissement pour pr&eacute;venir d'un probable disfonctionnement.");
define("_SENDAMSG","Envoyer un message");
define("_YOUSENDSTORY","Vous allez envoyer l'article");
define("_TOAFRIEND","&agrave; l'ami(e) suivant(e):");
define("_FYOURNAME","Votre nom:");
define("_FYOUREMAIL","Votre E-mail:");
define("_FFRIENDNAME","Nom de votre ami(e):");
define("_FFRIENDEMAIL","E-mail de votre ami(e):");
define("_INTERESTING","Lu sur");
define("_HELLO","Bonjour");
define("_YOURFRIEND","Votre ami(e)");
define("_CONSIDERED","a trouv l'article suivant intressant et a souhait vous l'envoyer.");
define("_FDATE","Date:");
define("_FTOPIC","Sujet:");
define("_YOUCANREAD","Vous pouvez lire d'autres articles intressant sur");
define("_FSTORY","L'article");
define("_HASSENT"," a &eacute;t&eacute; envoy&eacute; &agrave;");
define("_THANKS","Merci!");
define("_RECOMMEND","Recommander ce site &agrave; un(e) ami(e)");
define("_PDATE","Date:");
define("_PTOPIC","Sujet:");
define("_COMESFROM","Cet article provient de");
define("_THEURL","L'URL de cet article est:");





define("_PREVIEW","Prvisualisation");
define("_NEWUSER","Nouvel Utilisateur");
define("_OPTIONS","Options");


define("_REFRESH","Rafra&icirc;chir");
define("_ADD","Ajouter");
define("_NOCOMMENTSACT","Dsol, les Commentaires ne sont pas autoriss pour cet article.");
define("_ARTICLEPOLL","Sondage de l'arcticle");
define("_RATEARTICLE","Article Rating");
define("_RATETHISARTICLE","Please take a second and vote for this article:");
define("_CASTMYVOTE","Cast my Vote!");
define("_AVERAGESCORE","Average Score");
define("_BAD","Bad");
define("_REGULAR","Regular");
define("_GOOD","Good");
define("_VERYGOOD","Very Good");
define("_EXCELLENT","Excellent");
define("_ARTICLERATING","Article Rating");
define("_THANKSVOTEARTICLE","Thanks for voting for this article!");
define("_ALREADYVOTEDARTICLE","Sorry, you already voted for this article recently!");
define("_BACKTOARTICLEPAGE","Back to Article's Page");
define("_DIDNTRATE","You didn't selected any score for the article!");
define("_NOINFO4TOPIC","Sorry, there isn't information for the selected topic.");
define("_GOTONEWSINDEX","Go to News Index");
define("_SELECTNEWTOPIC","Select a New Topic");
define("_GOTOHOME","Go to Home");
define("_SEARCHONTOPIC","Search on This Topic");

?>
